@@ -1,6 +1,6 @@
 /* FAudio - XAudio Reimplementation for FNA
  *
- * Copyright (c) 2011-2018 Ethan Lee, Luigi Auriemma, and the MonoGame Team
+ * Copyright (c) 2011-2020 Ethan Lee, Luigi Auriemma, and the MonoGame Team
  *
  * This software is provided 'as-is', without any express or implied warranty.
  * In no event will the authors be held liable for any damages arising from
@@ -342,16 +342,16 @@ typedef struct FAudioDebugConfiguration
 #define FAUDIO_DEFAULT_CHANNELS		0
 #define FAUDIO_DEFAULT_SAMPLERATE	0
 
-#define FAUDIO_DEBUG_ENGINE		0x01
-#define FAUDIO_VOICE_NOPITCH		0x02
-#define FAUDIO_VOICE_NOSRC		0x04
-#define FAUDIO_VOICE_USEFILTER		0x08
-#define FAUDIO_VOICE_MUSIC		0x10
-#define FAUDIO_PLAY_TAILS		0x20
-#define FAUDIO_END_OF_STREAM		0x40
-#define FAUDIO_SEND_USEFILTER		0x80
-
+#define FAUDIO_DEBUG_ENGINE		0x0001
+#define FAUDIO_VOICE_NOPITCH		0x0002
+#define FAUDIO_VOICE_NOSRC		0x0004
+#define FAUDIO_VOICE_USEFILTER		0x0008
+#define FAUDIO_VOICE_MUSIC		0x0010
+#define FAUDIO_PLAY_TAILS		0x0020
+#define FAUDIO_END_OF_STREAM		0x0040
+#define FAUDIO_SEND_USEFILTER		0x0080
 #define FAUDIO_VOICE_NOSAMPLESPLAYED	0x0100
+#define FAUDIO_1024_QUANTUM		0x8000
 
 #define FAUDIO_DEFAULT_FILTER_TYPE	FAudioLowPassFilter
 #define FAUDIO_DEFAULT_FILTER_FREQUENCY	FAUDIO_MAX_FILTER_FREQUENCY
@@ -390,7 +390,7 @@ typedef struct FAudioDebugConfiguration
 #define _SPEAKER_POSITIONS_
 #endif
 
-#ifndef _SPEAKER_COMBINATIONS_
+#ifndef SPEAKER_MONO
 #define SPEAKER_MONO	SPEAKER_FRONT_CENTER
 #define SPEAKER_STEREO	(SPEAKER_FRONT_LEFT | SPEAKER_FRONT_RIGHT)
 #define SPEAKER_2POINT1 \
@@ -446,7 +446,6 @@ typedef struct FAudioDebugConfiguration
 		SPEAKER_SIDE_LEFT	| \
 		SPEAKER_SIDE_RIGHT	)
 #define SPEAKER_XBOX SPEAKER_5POINT1
-#define _SPEAKER_COMBINATIONS_
 #endif
 
 #define FAUDIO_FORMAT_PCM		1
@@ -454,6 +453,7 @@ typedef struct FAudioDebugConfiguration
 #define FAUDIO_FORMAT_IEEE_FLOAT	3
 #define FAUDIO_FORMAT_WMAUDIO2		0x0161
 #define FAUDIO_FORMAT_WMAUDIO3		0x0162
+#define FAUDIO_FORMAT_WMAUDIO_LOSSLESS	0x0163
 #define FAUDIO_FORMAT_XMAUDIO2		0x0166
 #define FAUDIO_FORMAT_EXTENSIBLE	0xFFFE
 
@@ -465,8 +465,8 @@ extern FAudioGUID DATAFORMAT_SUBTYPE_IEEE_FLOAT;
 #define FAUDIO_TARGET_VERSION 8 /* Targeting compatibility with XAudio 2.8 */
 
 #define FAUDIO_ABI_VERSION	 0
-#define FAUDIO_MAJOR_VERSION	19
-#define FAUDIO_MINOR_VERSION	 8
+#define FAUDIO_MAJOR_VERSION	20
+#define FAUDIO_MINOR_VERSION	 6
 #define FAUDIO_PATCH_VERSION	 0
 
 #define FAUDIO_COMPILED_VERSION ( \
